import time
import serial
import pyautogui
from win10toast import ToastNotifier

# Creates the toast notifier that will keep track of the notifications.
toast = ToastNotifier()


def show_toast(text, duration=0.1):
    """
    Creates a Windows 10 toast notification.
    :param text: The text that will be displayed in the notification.
    :param duration: The notification will be visible for this number of seconds.
    """
    toast.show_toast(
        "Gesture controlled music player",
        text,
        icon_path="logo.ico",
        duration=duration)


# Creates serial communication with the Arduino board.
arduino = serial.Serial('COM4', 9600)

# Waits 2 seconds for the communication to get established.
time.sleep(2)

# Creates the notifications.
show_toast("Hi there! How you doin'?")
show_toast("Put both your hands in front of the sensors to start the magic")

# Waits for all the notifications to be closed.
while toast.notification_active():
    time.sleep(1)

# Uses the serial port to mark the established connection.
arduino.write("start".encode())

# Waits for input from Arduino.
while 1:
    # Reads the gesture and uses the associated shortcut.
    data = str(arduino.readline())
    print(data)

    if 'play/pause' in data:
        pyautogui.press('k')

    if 'volume up' in data:
        # Increases the volume by 10%.
        [pyautogui.press('up') for _ in range(2)]

    if 'volume down' in data:
        # Decreases the volume by 10%.
        [pyautogui.press('down') for _ in range(2)]

    if 'swipe right' in data:
        pyautogui.keyDown('shift')
        pyautogui.press('n')
        pyautogui.keyUp('shift')

    if 'swipe left' in data:
        pyautogui.keyDown('shift')
        pyautogui.press('p')
        pyautogui.keyUp('shift')
